<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Point</name>
    <message>
        <location filename="../Point.js" line="+71"/>
        <source>Point Tools</source>
        <translation>Nástroje bodu</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show point tools</source>
        <translation>Zobrazit nástroje bodu</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Point</source>
        <translation>&amp;Bod</translation>
    </message>
</context>
</TS>
